@@ -25,3 +25,9 @@ SHAPES_DEFAULT_NAMESPACE = "http://weso.es/shapes/"
 #COMPRESSION FORMATS
 ZIP = "zip"
 GZ = "gz"
+
+# FREQUENCY MODES
+
+RATIO_INSTANCES = "ratio"
+ABSOLUTE_INSTANCES = "abs"
+MIXED_INSTANCES = "mixed"
